##  Using Dataflows
When importing large volumes of data into Microsoft Power BI, you might encounter issues in retrieving complete datasets. Using dataflows can help address these issues. Consider using dataflows when:
  * You need to combine data from multiple sources.
  * You need to transform data before loading it into reports.
  * You're dealing with large datasets and need efficient methods for processing and storing the data.
  * You need to regularly update your data, but only want to refresh the new or modified data, not the entire dataset.
  * You want to create reusable and centralized data models for multiple reports.


To learn how to create dataflows, refer to the [Microsoft documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fpower-bi%2Ftransform-model%2Fdataflows%2Fdataflows-introduction-self-service "https://learn.microsoft.com/en-us/power-bi/transform-model/dataflows/dataflows-introduction-self-service").
